@@ -37,10 +37,7 @@ gar_batch <- function(call_list, ...){
   ## call doHttrRequest with batched together functions
   cached_call <- !is.null(gar_cache_get_loc())
   if(cached_call){
-    req <- memDoBatchRequest(l, 
-                             function_list = function_list, 
-                             applyDataParseFunction = applyDataParseFunction, 
-                             ...)
+    req <- memDoBatchRequest(l)
   } else {
     req <- doBatchRequest(l)
   }
@@ -56,9 +53,13 @@ gar_batch <- function(call_list, ...){
   }
   
   ## now only one function allowed, this is shortcut to use only first function's data_parse
-  applyDataParseFunction(function_list, batch_content, ...)
-
+  f <- function_list[[1]]$data_parse_function
   
+  batch_content_content <- lapply(batch_content, function(x) x$content[[1]])
+  
+  ## apply data parse function from function_list$data_parse_function
+  lapply(batch_content_content, f, ... = ...)
+
 }
 
 
@@ -158,29 +159,6 @@ gar_batch_walk <- function(f,
 
   the_data
 }
-  
-  
-  
-
-#' Apply parsing function if a good response
-#' 
-#' @param function_entry a Google API function generated by \code{gar_api_generator}
-#' @param the content returned from a batch call
-#' 
-#' @keywords internal
-#' @family batch functions
-#' @noRd
-applyDataParseFunction <- function(function_list, batch_content, ...){
-
-  ## we only need first data_parse_function as all the same
-  f <- function_list[[1]]$data_parse_function
-  
-  batch_content_content <- lapply(batch_content, function(x) x$content[[1]])
-  
-  ## apply data parse function from function_list$data_parse_function
-  lapply(batch_content_content, f, ... = ...)
-  
-}
 
 
 #' Parse batch request
