@@ -94,10 +94,12 @@ gar_api_generator <- function(baseURI,
   }
 
   if(!is.null(pars_args)){
+    ## it has to be a character for pars
+    pars_args <- vapply(pars_args, as.character, character(1))
     pars <-
       paste(names(pars_args), 
-            vapply(pars_args, URLencode, reserved = TRUE, names(pars_args)), 
-            sep='=', collapse='&')
+            vapply(pars_args, URLencode, reserved = TRUE, character(1)), 
+            sep='=', collapse='&')    
 
   }
 
